@@ -28,6 +28,7 @@ extern void clear_tabs(void);
 extern void add_tab(uint tabi, HWND wndi);
 extern void win_tab_left(void);
 extern void win_tab_right(void);
+extern void win_tab_move(int n);
 // Inter-window actions
 enum {
   WIN_MINIMIZE = 0,
@@ -89,6 +90,7 @@ extern uint dpi;
 extern int per_monitor_dpi_aware;
 extern bool keep_screen_on;
 extern bool force_opaque;
+extern bool checked_desktop_config;
 
 extern bool click_focus_token;
 extern pos last_pos;
